Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(417)

Unified Diff: runtime/vm/flow_graph_builder.cc

Issue 11523002: Pass the proper invocation mirror argument to noSuchMethod. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/code_generator.cc ('k') | runtime/vm/parser.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/flow_graph_builder.cc
===================================================================
--- runtime/vm/flow_graph_builder.cc (revision 15938)
+++ runtime/vm/flow_graph_builder.cc (working copy)
@@ -2809,7 +2809,13 @@
ArgumentListNode* arguments = new ArgumentListNode(args_pos);
// The first argument is the original method name.
arguments->Add(new LiteralNode(args_pos, method_name));
- // The second argument is an array containing the original method arguments.
+ // The second argument is the arguments descriptor of the original method.
+ const Array& args_descriptor =
+ Array::ZoneHandle(ArgumentsDescriptor::New(method_arguments->length(),
+ method_arguments->names()));
+ arguments->Add(new LiteralNode(args_pos, args_descriptor));
+ // The third argument is an array containing the original method arguments,
+ // including the receiver.
ArrayNode* args_array =
new ArrayNode(args_pos, Type::ZoneHandle(Type::ArrayType()));
for (intptr_t i = 0; i < method_arguments->length(); i++) {
« no previous file with comments | « runtime/vm/code_generator.cc ('k') | runtime/vm/parser.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698